@@ -4,7 +4,8 @@
 
 #include <stdio.h>
 #include <ctype.h>
-#ifdef MSDOS
+#ifdef WINDOWSNT
+#include <io.h>
 #include <fcntl.h>
 #endif
 
@@ -141,9 +142,8 @@ main (int argc, char *argv[])
 	{
 	  char buf[18];
 
-#ifdef MSDOS
-	  (stdout)->_flag &= ~_IOTEXT; /* print binary */
-	  _setmode (fileno (stdout), O_BINARY);
+#ifdef WINDOWSNT
+	  _setmode (_fileno (stdout), O_BINARY);
 #endif
 	  for (;;)
 	    {
@@ -185,9 +185,8 @@ main (int argc, char *argv[])
 	}
       else
 	{
-#ifdef MSDOS
-	  (fp)->_flag &= ~_IOTEXT; /* read binary */
-	  _setmode (fileno (fp), O_BINARY);
+#ifdef WINDOWSNT
+	  _setmode (_fileno (fp), O_BINARY);
 #endif
 	  address = 0;
 	  string[0] = ' ';
