@@ -31,7 +31,7 @@ void update_frame_menubars (struct frame *f);
 void free_frame_menubars (struct frame *f);
 Lisp_Object menu_parse_submenu_keywords (Lisp_Object desc,
 					 Lisp_Object gui_item);
-Lisp_Object current_frame_menubar (CONST struct frame* f);
+Lisp_Object current_frame_menubar (const struct frame* f);
 
 EXFUN (Fmenu_find_real_submenu, 2);
 
