@@ -202,8 +202,8 @@ void sleep (int seconds);
 
 /* subprocess calls that are emulated */
 #define spawnve sys_spawnve
-int spawnve (int mode, CONST char *cmdname, 
-	     CONST char * CONST *argv, CONST char *CONST *envp);
+int spawnve (int mode, const char *cmdname, 
+	     const char * const *argv, const char *const *envp);
 
 #define wait    sys_wait
 int wait (int *status);
