@@ -55,12 +55,6 @@ Boston, MA 02111-1307, USA.  */
 #define LINKER "gcc"
 #endif
 
-#undef LIBX11_SYSTEM
-#define LIBX11_SYSTEM "-lsocket"
-
-#undef LIB_X11_LIB
-#define LIB_X11_LIB "-lX11 -lgen"
-
 #define LIBS_SYSTEM "-lsocket -lPW -lgen -lcrypt -lmalloc"
 
 #ifndef MAXPATHLEN
@@ -107,9 +101,6 @@ could #define sco and I think everything would work. rjl */
 #endif
 #define LIB_STANDARD "-lc"
 
-/* Send signals to subprocesses by "typing" signal chars at them.  */
-/* #define SIGNALS_VIA_CHARACTERS */ /* mrb */
-
 /* Specify program for etc/fakemail to run.  Define SMAIL if you are
    using smail, don't for MMDF.  */
 
@@ -134,14 +125,8 @@ could #define sco and I think everything would work. rjl */
 #ifdef _SCO_ELF
 #undef COFF /* coz we're NOT */
 #define UNEXEC "unexelf.o"
-#if defined (__GNUC_MINOR__)
-#if ((__GNUC__ == 2) && (__GNUC_MINOR__ > 7)) || ((__GNUC__ > 2))
-#define LIB_GCC "-lgcc"
-#else
-#define LIB_GCC "-lgcc-elf"
-#endif
-#else /* __GNUC_MINOR__ is undefined */
-#define LIB_GCC "-lgcc-elf"
-#endif
 #endif
 
+/* For GCC 2.7.2.3 we require the "JKJ" version of gcc.
+   Works fine with egcs and gcc 2.8.x. */
+#define LIB_GCC "`$(LD) $(LDFLAGS) -print-libgcc-file-name`"
