@@ -48,10 +48,6 @@ Boston, MA 02111-1307, USA.  */
 
 /* #define HAVE_PTYS */
 
-/* Define this macro if system defines a type `union wait'.  */
-
-#define HAVE_UNION_WAIT
-
 #define NO_SUBPROCESSES
 
 /* If your system uses COFF (Common Object File Format) then define the
@@ -66,16 +62,6 @@ Boston, MA 02111-1307, USA.  */
 
 /* #define MAIL_USE_FLOCK */
 
-/* Define SHORTNAMES if the C compiler can distinguish only
-   short names.  It means that the stuff in ../shortnames
-   must be run to convert the long names to short ones.
-
-   Some USG systems support long names.
-   If yours is one, DO NOT change this file!
-   Do #undef SHORTNAMES in the m- file or in config.h.  */
-
-#define SHORTNAMES
-
 /* The file containing the kernel's symbol table is called /unix.  */
 
 #define KERNEL_FILE "/unix"
@@ -103,8 +89,8 @@ Boston, MA 02111-1307, USA.  */
 
 /* Special library needed for linking for Uniplus */
 
-#define LIBS_SYSTEM -lnet
+#define LIBS_SYSTEM "-lnet"
 
 /* A system-specific loader switch is needed.  */
 
-#define LD_SWITCH_SYSTEM -N -L/lib/libg /usr/lib/unshared.ld
+#define LD_SWITCH_SYSTEM "-N -L/lib/libg /usr/lib/unshared.ld"
