@@ -21,9 +21,6 @@ Boston, MA 02111-1307, USA.  */
 
 /* Synched up with: Not synched with FSF.  Split out of keyboard.c. */
 
-/* Just to make sure we don't use any global vars below */
-#define DONT_DECLARE_MAC_VARS
-
 #include <config.h>
 #include "lisp.h"
 
@@ -34,6 +31,9 @@ Boston, MA 02111-1307, USA.  */
 #include "syssignal.h"
 #include "systime.h"
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include <errno.h>
 
 /* Set to 1 when a quit-check signal (either a SIGIO interrupt or
@@ -63,7 +63,7 @@ int dont_check_for_quit;
 int poll_for_quit_id;
 #endif
 
-#ifndef SIGCHLD
+#if defined(HAVE_UNIX_PROCESSES) && !defined(SIGCHLD)
 int poll_for_sigchld_id;
 #endif
 
@@ -180,6 +180,9 @@ alarm_signal (int signo)
 	 it needs to stay the way it is. */
       quit_check_signal_happened = 1;
 
+#ifdef WINDOWSNT
+      can_break_system_calls = 0;
+#else
       /* can_break_system_calls is set when we want to break out of
 	 non-interruptible system calls. */
       if (can_break_system_calls)
@@ -192,6 +195,7 @@ alarm_signal (int signo)
 	  EMACS_REESTABLISH_SIGNAL (signo, alarm_signal);
 	  LONGJMP (break_system_call_jump, 0);
 	}
+#endif
 
       EMACS_REESTABLISH_SIGNAL (signo, alarm_signal);
       SIGRETURN;
@@ -207,7 +211,10 @@ alarm_signal (int signo)
      went off.  Rather than put the code in to compute this
      specially, we just set this flag.  Should fix this. */
   quit_check_signal_happened = 1;
+
+#ifdef HAVE_UNIXOID_EVENT_LOOP
   signal_fake_event ();
+#endif
 
   EMACS_REESTABLISH_SIGNAL (signo, alarm_signal);
   SIGRETURN;
@@ -302,7 +309,7 @@ handle_alarm_going_off (void)
 
      #### This is a bit inefficient because there will be function call
      overhead each time QUIT occurs. */
-     
+
   if (!NILP (Vinhibit_quit))
     {
       something_happened = 1;
@@ -348,11 +355,11 @@ Return non-nil if XEmacs is waiting for input from the user.
 This is intended for use by asynchronous timeout callbacks and by
 asynchronous process output filters and sentinels (not yet implemented
 in XEmacs).  It will always be nil if XEmacs is not inside of
-an asynchronout timeout or process callback.
+an asynchronous timeout or process callback.
 */
        ())
 {
-  return ((waiting_for_user_input_p) ? Qt : Qnil);
+  return waiting_for_user_input_p ? Qt : Qnil;
 }
 
 
@@ -406,19 +413,11 @@ interrupt_signal (int sig)
  */
       sys_suspend ();
 #else
-#ifdef VMS
-      if (sys_suspend () == -1)
-	{
-	  stdout_out ("Not running as a subprocess;\n");
-	  stdout_out ("you can continue or abort.\n");
-	}
-#else /* not VMS */
       /* Perhaps should really fork an inferior shell?
 	 But that would not provide any way to get back
 	 to the original shell, ever.  */
       stdout_out ("No support for stopping a process on this operating system;\n");
       stdout_out ("you can continue or abort.\n");
-#endif /* not VMS */
 #endif /* not SIGTSTP */
       stdout_out ("Auto-save? (y or n) ");
       fflush (stdout);
@@ -426,11 +425,7 @@ interrupt_signal (int sig)
 	Fdo_auto_save (Qnil, Qnil);
       while (c != '\n')
         c = getc (stdin);
-#ifdef VMS
-      stdout_out ("Abort (and enter debugger)? (y or n) ");
-#else /* not VMS */
       stdout_out ("Abort (and dump core)? (y or n) ");
-#endif /* not VMS */
       fflush (stdout);
       if (((c = getc (stdin)) & ~040) == 'Y')
 	abort ();
@@ -450,7 +445,9 @@ interrupt_signal (int sig)
       /* Else request quit when it's safe */
       Vquit_flag = Qt;
       sigint_happened = 1;
+#ifdef HAVE_UNIXOID_EVENT_LOOP
       signal_fake_event ();
+#endif
     }
   errno = old_errno;
   SIGRETURN;
@@ -474,7 +471,7 @@ begin_dont_check_for_quit (void)
 
 /* The effect of this function is to set Vquit_flag if the user pressed
    ^G and discard the ^G, so as to not notice the same ^G again. */
-int 
+int
 check_quit (void)
 {
   /* dont_check_for_quit is set in two circumstances:
@@ -523,7 +520,7 @@ check_what_happened (void)		/* called from QUIT when
   return check_quit ();
 }
 
-  
+
 
 void
 init_poll_for_quit (void)
@@ -555,7 +552,7 @@ reset_poll_for_quit (void)
 #endif /* not SIGIO and not DONT_POLL_FOR_QUIT */
 }
 
-#ifndef SIGCHLD
+#if defined(HAVE_UNIX_PROCESSES) && !defined(SIGCHLD)
 
 static void
 init_poll_for_sigchld (void)
@@ -601,7 +598,7 @@ stop_interrupts (void)
 {
   if (!interrupts_initted)
     return;
-#ifdef SIGIO
+#if defined(SIGIO) && !defined(BROKEN_SIGIO)
   unrequest_sigio ();
 #endif
   stop_async_timeouts ();
@@ -612,7 +609,7 @@ start_interrupts (void)
 {
   if (!interrupts_initted)
     return;
-#ifdef SIGIO
+#if defined(SIGIO) && !defined(BROKEN_SIGIO)
   request_sigio ();
 #endif
   start_async_timeouts ();
@@ -634,107 +631,132 @@ emacs_sleep (int secs)
 /*                            initialization                            */
 /************************************************************************/
 
+/* If we've been nohup'ed, keep it that way.
+   This allows `nohup xemacs &' to work.
+   More generally, if a normally fatal signal has been redirected
+   to SIG_IGN by our invocation environment, trust the environment.
+   This keeps xemacs from being killed by a SIGQUIT intended for a
+   different process after having been backgrounded under a
+   non-job-control shell! */
+static void
+handle_signal_if_fatal (int signo)
+{
+  if (signal (signo,  fatal_error_signal) == SIG_IGN)
+    signal (signo, SIG_IGN);
+}
+
 void
 init_signals_very_early (void)
 {
-  /* Catch all signals that would kill us. */
-  if (! noninteractive || initialized)
-    {
-      /* Don't catch these signals in batch mode if not initialized.
-	 On some machines, this sets static data that would make
-	 signal fail to work right when the dumped Emacs is run.  */
-      signal (SIGHUP,  fatal_error_signal);
-      signal (SIGQUIT, fatal_error_signal);
-      signal (SIGILL,  fatal_error_signal);
-      signal (SIGTRAP, fatal_error_signal);
-#ifdef SIGABRT
-      signal (SIGABRT, fatal_error_signal);
-#endif
-#ifdef SIGHWE
-      signal (SIGHWE, fatal_error_signal);
-#endif
-#ifdef SIGPRE
-      signal (SIGPRE, fatal_error_signal);
-#endif
-#ifdef SIGORE
-      signal (SIGORE, fatal_error_signal);
-#endif
-#ifdef SIGUME
-      signal (SIGUME, fatal_error_signal);
-#endif
-#ifdef SIGDLK
-      signal (SIGDLK, fatal_error_signal);
-#endif
-#ifdef SIGCPULIM
-      signal (SIGCPULIM, fatal_error_signal);
-#endif
-#ifdef SIGIOT
-      signal (SIGIOT, fatal_error_signal);
-#endif
-#ifdef SIGEMT
-      signal (SIGEMT, fatal_error_signal);
-#endif
-      signal (SIGFPE, fatal_error_signal);
-#ifdef SIGBUS
-      signal (SIGBUS, fatal_error_signal);
-#endif
-      signal (SIGSEGV, fatal_error_signal);
-#ifdef SIGSYS
-      signal (SIGSYS, fatal_error_signal);
-#endif
-      signal (SIGPIPE, fatal_error_signal);
-      signal (SIGTERM, fatal_error_signal);
-#ifdef SIGXCPU
-      signal (SIGXCPU, fatal_error_signal);
-#endif
-#ifdef SIGXFSZ
-      signal (SIGXFSZ, fatal_error_signal);
-#endif /* SIGXFSZ */
+  /* Catch all signals that would kill us.
+     Don't catch these signals in batch mode if not initialized.
+     On some machines, this sets static data that would make
+     signal fail to work right when the dumped Emacs is run.  */
+  if (noninteractive && !initialized)
+    return;
 
-#ifdef SIGDANGER
-      /* This just means available memory is getting low.  */
-      signal (SIGDANGER, memory_warning_signal);
-#endif
+  handle_signal_if_fatal (SIGILL);  /* ANSI */
+  handle_signal_if_fatal (SIGABRT); /* ANSI */
+  handle_signal_if_fatal (SIGFPE);  /* ANSI */
+  handle_signal_if_fatal (SIGSEGV); /* ANSI */
+  handle_signal_if_fatal (SIGTERM); /* ANSI */
 
-#ifdef SIGLOST
-      signal (SIGLOST, fatal_error_signal);
+
+#ifdef SIGHUP
+  handle_signal_if_fatal (SIGHUP);  /* POSIX */
 #endif
-#ifdef SIGSTKFLT /* coprocessor stack fault under Linux */
-      signal (SIGSTKFLT, fatal_error_signal);
+#ifdef SIGQUIT
+  handle_signal_if_fatal (SIGQUIT); /* POSIX */
+#endif
+#ifdef SIGTRAP
+  handle_signal_if_fatal (SIGTRAP); /* POSIX */
 #endif
 #ifdef SIGUSR1
-      signal (SIGUSR1, fatal_error_signal);
+  handle_signal_if_fatal (SIGUSR1); /* POSIX */
 #endif
 #ifdef SIGUSR2
-      signal (SIGUSR2, fatal_error_signal);
+  handle_signal_if_fatal (SIGUSR2); /* POSIX */
+#endif
+#ifdef SIGPIPE
+  handle_signal_if_fatal (SIGPIPE); /* POSIX */
 #endif
 #ifdef SIGALRM
-      /* This will get reset later, once we're capable of handling
-	 this properly. */
-      signal (SIGALRM, fatal_error_signal);
+  /* This will get reset later, once we're
+     capable of handling it properly. */
+  handle_signal_if_fatal (SIGALRM); /* POSIX */
+#endif
+
+
+#ifdef SIGBUS
+  handle_signal_if_fatal (SIGBUS);  /* XPG5 */
+#endif
+#ifdef SIGSYS
+  handle_signal_if_fatal (SIGSYS);  /* XPG5 */
+#endif
+#ifdef SIGXCPU
+  handle_signal_if_fatal (SIGXCPU); /* XPG5 */
+#endif
+#ifdef SIGXFSZ
+  handle_signal_if_fatal (SIGXFSZ); /* XPG5 */
 #endif
 #ifdef SIGVTALRM
-      signal (SIGVTALRM, fatal_error_signal);
+  handle_signal_if_fatal (SIGVTALRM); /* XPG5 */
 #endif
 #ifdef SIGPROF
-      /* Messes up the REAL profiler */
-      /* signal (SIGPROF, fatal_error_signal); */
+  /* Messes up the REAL profiler */
+  /* handle_signal_if_fatal (SIGPROF); */ /* XPG5 */
+#endif
+
+
+#ifdef SIGHWE
+  handle_signal_if_fatal (SIGHWE);
+#endif
+#ifdef SIGPRE
+  handle_signal_if_fatal (SIGPRE);
+#endif
+#ifdef SIGORE
+  handle_signal_if_fatal (SIGORE);
+#endif
+#ifdef SIGUME
+  handle_signal_if_fatal (SIGUME);
+#endif
+#ifdef SIGDLK
+  handle_signal_if_fatal (SIGDLK);
+#endif
+#ifdef SIGCPULIM
+  handle_signal_if_fatal (SIGCPULIM);
+#endif
+#ifdef SIGIOT
+  handle_signal_if_fatal (SIGIOT);
+#endif
+#ifdef SIGEMT
+  handle_signal_if_fatal (SIGEMT);
+#endif
+#ifdef SIGLOST
+  handle_signal_if_fatal (SIGLOST);
+#endif
+#ifdef SIGSTKFLT /* coprocessor stack fault under Linux */
+  handle_signal_if_fatal (SIGSTKFLT);
 #endif
 #ifdef SIGUNUSED /* exists under Linux, and will kill process! */
-      signal (SIGUNUSED, fatal_error_signal);
+  handle_signal_if_fatal (SIGUNUSED);
 #endif
 
 #ifdef AIX
 /* 20 is SIGCHLD, 21 is SIGTTIN, 22 is SIGTTOU.  */
 #ifndef _I386
-      signal (SIGIOINT, fatal_error_signal);
+  handle_signal_if_fatal (SIGIOINT);
 #endif
-      signal (SIGGRANT,   fatal_error_signal);
-      signal (SIGRETRACT, fatal_error_signal);
-      signal (SIGSOUND,   fatal_error_signal);
-      signal (SIGMSG,     fatal_error_signal);
+  handle_signal_if_fatal (SIGGRANT);
+  handle_signal_if_fatal (SIGRETRACT);
+  handle_signal_if_fatal (SIGSOUND);
+  handle_signal_if_fatal (SIGMSG);
 #endif /* AIX */
-    }
+
+#ifdef SIGDANGER
+  /* This just means available memory is getting low.  */
+  signal (SIGDANGER, memory_warning_signal);
+#endif
 }
 
 void
@@ -757,7 +779,7 @@ init_interrupts_late (void)
       init_async_timeouts ();
 #ifdef SIGIO
       signal (SIGIO, input_available_signal);
-# ifdef SIGPOLL
+# ifdef SIGPOLL /* XPG5 */
       /* Some systems (e.g. Motorola SVR4) losingly have different
 	 values for SIGIO and SIGPOLL, and send SIGPOLL instead of
 	 SIGIO.  On those same systems, an uncaught SIGPOLL kills the
@@ -769,7 +791,7 @@ init_interrupts_late (void)
 #endif
     }
 
-#ifndef SIGCHLD
+#if defined(HAVE_UNIX_PROCESSES) && !defined(SIGCHLD)
   init_poll_for_sigchld ();
 #endif
 
